@@ -4,7 +4,10 @@
 
 #include "videoinfoextractor.h"
 
-#include <asyncytmusic.h>
+#include <QFutureWatcher>
+
+#include "asyncytmusic.h"
+#include "library.h"
 
 VideoInfoExtractor::VideoInfoExtractor(QObject *parent)
     : QObject(parent)
@@ -14,22 +17,26 @@ VideoInfoExtractor::VideoInfoExtractor(QObject *parent)
             m_videoInfo = {};
             Q_EMIT audioUrlChanged();
             Q_EMIT titleChanged();
+            Q_EMIT artistChanged();
+            Q_EMIT channelChanged();
             Q_EMIT songChanged();
             Q_EMIT thumbnailChanged();
             return;
         }
 
         setLoading(true);
-        YTMusicThread::instance()->extractVideoInfo(QString::fromStdString(m_videoId.toStdString()));
-    });
 
-    connect(&YTMusicThread::instance().get(), &AsyncYTMusic::extractVideoInfoFinished, this, [this](const video_info::VideoInfo &info) {
-        m_videoInfo = info;
-        setLoading(false);
-        Q_EMIT audioUrlChanged();
-        Q_EMIT titleChanged();
-        Q_EMIT songChanged();
-        Q_EMIT thumbnailChanged();
+        auto future = YTMusicThread::instance()->extractVideoInfo(QString::fromStdString(m_videoId.toStdString()));
+        connectFuture(future, this, [this](const video_info::VideoInfo &videoInfo) {
+            m_videoInfo = videoInfo;
+            setLoading(false);
+            Q_EMIT audioUrlChanged();
+            Q_EMIT titleChanged();
+            Q_EMIT artistChanged();
+            Q_EMIT channelChanged();
+            Q_EMIT songChanged();
+            Q_EMIT thumbnailChanged();
+        });
     });
 }
 
@@ -66,6 +73,9 @@ QString VideoInfoExtractor::videoId() const
 
 void VideoInfoExtractor::setVideoId(const QString &videoId)
 {
+    if (m_videoId == videoId || videoId.isEmpty()) {
+        return;
+    }
     m_videoId = videoId;
     Q_EMIT videoIdChanged();
 }
@@ -75,6 +85,16 @@ QString VideoInfoExtractor::title() const
     return QString::fromStdString(m_videoInfo.title);
 }
 
+QString VideoInfoExtractor::artist() const
+{
+    return QString::fromStdString(m_videoInfo.artist);
+}
+
+QString VideoInfoExtractor::channel() const
+{
+    return QString::fromStdString(m_videoInfo.channel);
+}
+
 QString VideoInfoExtractor::thumbnail() const
 {
     return QString::fromStdString(m_videoInfo.thumbnail);
